@@ -419,7 +419,7 @@ class ImportTask(BaseImportTask):
       from the `candidates` list.
 
     * `find_duplicates()` Returns a list of albums from `lib` with the
-       same artist and album name as the task.
+      same artist and album name as the task.
 
     * `apply_metadata()` Sets the attributes of the items from the
       task's `match` attribute.
@@ -429,6 +429,9 @@ class ImportTask(BaseImportTask):
     * `manipulate_files()` Copy, move, and write files depending on the
       session configuration.
 
+    * `set_fields()` Sets the fields given at CLI or configuration to
+      the specified values.
+
     * `finalize()` Update the import progress and cleanup the file
       system.
     """
@@ -530,6 +533,19 @@ class ImportTask(BaseImportTask):
                 util.prune_dirs(os.path.dirname(item.path),
                                 lib.directory)
 
+    def set_fields(self):
+        """Sets the fields given at CLI or configuration to the specified
+        values.
+        """
+        for field, view in config['import']['set_fields'].items():
+            value = view.get()
+            log.debug(u'Set field {1}={2} for {0}',
+                      displayable_path(self.paths),
+                      field,
+                      value)
+            self.album[field] = value
+        self.album.store()
+
     def finalize(self, session):
         """Save progress, clean up files, and emit plugin event.
         """
@@ -877,6 +893,19 @@ class SingletonImportTask(ImportTask):
     def reload(self):
         self.item.load()
 
+    def set_fields(self):
+        """Sets the fields given at CLI or configuration to the specified
+        values.
+        """
+        for field, view in config['import']['set_fields'].items():
+            value = view.get()
+            log.debug(u'Set field {1}={2} for {0}',
+                      displayable_path(self.paths),
+                      field,
+                      value)
+            self.item[field] = value
+        self.item.store()
+
 
 # FIXME The inheritance relationships are inverted. This is why there
 # are so many methods which pass. More responsibility should be delegated to
@@ -1385,6 +1414,14 @@ def apply_choice(session, task):
 
     task.add(session.lib)
 
+    # If ``set_fields`` is set, set those fields to the
+    # configured values.
+    # NOTE: This cannot be done before the ``task.add()`` call above,
+    # because then the ``ImportTask`` won't have an `album` for which
+    # it can set the fields.
+    if config['import']['set_fields']:
+        task.set_fields()
+
 
 @pipeline.mutator_stage
 def plugin_stage(session, func, task):
